@@ -399,6 +399,26 @@ namespace Arc {
     case Job::SESSIONDIR:
       url.ChangePath(url.Path() + "/session");
       break;
+    case Job::LOGDIR:
+      url.ChangePath(url.Path() + "/diagnose");
+      {
+      URL file(url);
+      file.ChangePath(url.Path() + "/failed"); url.AddLocation(URLLocation(file, "failed"));
+      file.ChangePath(url.Path() + "/local"); url.AddLocation(URLLocation(file, "local"));
+      file.ChangePath(url.Path() + "/errors"); url.AddLocation(URLLocation(file, "errors"));
+      file.ChangePath(url.Path() + "/description"); url.AddLocation(URLLocation(file, "description"));
+      file.ChangePath(url.Path() + "/diag"); url.AddLocation(URLLocation(file, "diag"));
+      file.ChangePath(url.Path() + "/comment"); url.AddLocation(URLLocation(file, "comment"));
+      file.ChangePath(url.Path() + "/status"); url.AddLocation(URLLocation(file, "status"));
+      file.ChangePath(url.Path() + "/acl"); url.AddLocation(URLLocation(file, "acl"));
+      file.ChangePath(url.Path() + "/xml"); url.AddLocation(URLLocation(file, "xml"));
+      file.ChangePath(url.Path() + "/input"); url.AddLocation(URLLocation(file, "input"));
+      file.ChangePath(url.Path() + "/output"); url.AddLocation(URLLocation(file, "output"));
+      file.ChangePath(url.Path() + "/input_status"); url.AddLocation(URLLocation(file, "input_status"));
+      file.ChangePath(url.Path() + "/output_status"); url.AddLocation(URLLocation(file, "output_status"));
+      file.ChangePath(url.Path() + "/statistics"); url.AddLocation(URLLocation(file, "statistics"));
+      }
+      break;
     case Job::JOBLOG:
       url.ChangePath(url.Path() + "/diagnose/errors");
       break;
